@@ -35,7 +35,7 @@ class CeleryClient(object):
         self.rds_client.set(rs_key, callback.json(), ex=self.default_expire_seconds)
 
     # 异步请求
-    def apply_async(self, task_name: str, kwargs: Dict = None, callback: Callback = None):
+    def apply_async(self, task_name: str, task_params: Dict = None, callback: Callback = None, **kwargs):
         LOGGER.info(f'[服务]异步调用 task={task_name}')
         try:
             _headers = dict()
@@ -44,39 +44,42 @@ class CeleryClient(object):
             _headers['app_code'] = _headers.get('app_code', None) or self.app_code
 
             # 异步调用
-            async_result = self._get_task(task_name).apply_async(kwargs=kwargs, queue=f'task_queue.{task_name}', headers=_headers)
+            async_result = self._get_task(task_name).apply_async(kwargs=task_params, queue=f'task_queue.{task_name}', headers=_headers)
             # 绑定回调处理函数
             self._bind_callback(task_name, async_result, callback)
             return async_result
         except Exception as e:
-            LOGGER.error(f'处理异常: task_name={task_name}, kwargs={kwargs}, callback={callback}, e={e}')
+            LOGGER.error(f'处理异常: task_name={task_name}, kwargs={task_params}, callback={callback}, e={e}')
             raise e
 
     # 同步请求
-    def apply_sync(self, task_name: str, kwargs: Dict = None, timeout: float = None):
+    def apply_sync(self, task_name: str, task_params: Dict = None, **kwargs):
         LOGGER.info(f'[服务]同步调用 task={task_name}')
         try:
             _headers = {'app_code': self.app_code}
             # 异步调用
-            async_result = self._get_task(task_name).apply_async(kwargs=kwargs, queue=f'task_queue.{task_name}', headers=_headers)
+            async_result = self._get_task(task_name).apply_async(kwargs=task_params, queue=f'task_queue.{task_name}', headers=_headers)
             # 等待结果
-            return async_result.get(timeout=timeout)
+            _timeout = 60
+            if kwargs and kwargs.get('timeout', None):
+                _timeout = float(kwargs.get('timeout'))
+            return async_result.get(timeout=_timeout)
         except Exception as e:
-            LOGGER.error(f'处理异常: task_name={task_name}, kwargs={kwargs}, e={e}')
+            LOGGER.error(f'处理异常: task_name={task_name}, kwargs={task_params}, e={e}')
             raise e
 
     # 兼容方式请求调用
-    def apply(self, task_name: str, kwargs: Dict = None, callback: Callback = None, timeout: float = None):
+    def apply(self, task_name: str, task_params: Dict = None, callback: Callback = None, **kwargs):
         """
         兼容方式请求调用
         有callback怎为异步
         """
         if callback:
             # 异步
-            return self.apply_async(task_name=task_name, kwargs=kwargs, callback=callback)
+            return self.apply_async(task_name=task_name, task_params=task_params, callback=callback)
         else:
             # 同步
-            return self.apply_sync(task_name=task_name, kwargs=kwargs, timeout=timeout)
+            return self.apply_sync(task_name=task_name, task_params=task_params, **kwargs)
 
     # 缓存Celery任务对象
     def _get_task(self, task_name: str):
